@@ -6,8 +6,15 @@ class ArgumentsCollection(object):
         self.args = args
         self.kwargs = kwargs
 
+    @staticmethod
+    def argument_to_str(arg):
+        try:
+            return str(arg)
+        except UnicodeError:
+            return repr(arg)
+
     def __str__(self):
         arguments = list(map(repr, self.args))
         keys = sorted(self.kwargs.keys())
-        arguments = arguments + ['{0}({1})'.format(str(key), repr(self.kwargs[key])) for key in keys]
+        arguments = arguments + ['{0}({1})'.format(str(key), self.argument_to_str(self.kwargs[key])) for key in keys]
         return '_'.join(arguments)
\ No newline at end of file
